/******************************************
* config.h - Hard coded configuration info
*
* CVS $Id: config.h,v 1.17 2000/12/02 01:21:14 wcampbel Exp $
******************************************/

#ifndef CONFIG_H
#define CONFIG_H

/* Makefile and -D's were getting too much.  It's 
** a little more work to set a service up
** but it's vastly more configurable
*/

/* Many of the options from the Makefile are now here */

/* CRYPT stays in Makefile because of the possibility of a
** system without libcrypt, plus we need different libraries
** on different systems
*/

/* Solaris needs special options
** Win32 needs special options too
** They will PROBABLY remain in Makefile, at least for now
** as both systems require different CFLAGS and LDFLAGS
*/

/* Support fnmatch() - This is used to support masked servers
** eg *.fi *.au *.test.net.  This makes it non portable to some
** systems, Windows Cygwin included
** MOST networks do not need this, so it's disabled by default
** With it disabled, introducing a user on a server behind a mask
** will cause Stats to die.  The message when it dies will tell you
** to enable this option.  If you think that you will run a server
** with a mask, enable it now to prevent your service from dying
** NOTE:  It no longer crashes.  It sends out a message via WALLOPS
**        or GLOBOPS, logs the message in the log files, and gracefully
**        exits the service.
*/

#undef FNMATCH

/* This is a relatively new and feature.  It appears to be stable and 
** usable.  This may be permanently #define'ed in the future.  It's to 
** support the more secure method of communicating with a service, 
** PRIVMSG user@server :message
*/

#define SUPPORT_MSG_UH

/* This is another new feature... This is for support of the Hybrid 6
** NOTICE/PRIVMSG opers@server feature.  If this is enabled, all messages
** to opers@<my name> will be forwarded on to all logged in users.
** This does increase CPU usage and is relatively untested as of yet
** so it is disabled by default
*/

#undef SUPPORT_MSG_OPERS

/* Define this to have the service ignore illegal top level domains
** This is useful on servers that allow spoofs for either opers 
** or users.  Currently, this will just prevent logging of the illegal
** TLD's to the log file.  If there is a valid ICANN aproved TLD that is
** not working, please let me know so I can fix it.  
**
** NOTE:  I am not putting the Open Root Servers or the ADNS TLD's into
**        the official distribution.  If you use one or the other and
**        wish to have support, then you will have to create a TLD
**        table.  I could then distribute this TLD table along side the
**        official one.
*/

#undef IGNORE_ILLEGAL_TLD

/* This option enables the (currently in development) dynamically 
** changable settings module.  NOTE:  This does NOT currently save the
** settings you modify in here.  That support IS planned but has not been
** created.  Not all possible settings are included yet.  Some will never
** (and should not) be.  Do NOT use this on a development network yet!!!
**
** This is currently disabled and cannot be enabled.  It will work again
** when I complete it.
*/
#undef ENABLE_SET

/* If you dislike the service being able to JUPE, and were unhappy with
** JUPE being controlled by an entry in the config file, this is for you...
** JUPE must be #define'ed here to even exist in the service.
*/

#undef ENABLE_JUPE

/* This will enable or disable QUOTE/RAW, just as dangerous
** #define it to have it enabled
*/

#undef ENABLE_QUOTE

/* Large network support - The targeted audience of this package
** are small networks (Under 1000 users and 60 servers)
** Enabling this option will enlarge the data tables (and increase
** memory usage).  This is untested, and therefore may cause problems
** I would avoid enabling this until there is further testing
**
** This service will need to be heavily optimized to support a large
** number of users.  The optimization HAS begun, but is far from complete.
*/

#undef LARGE_NET

/* You MUST set this or RESTART won't work!!!!
** Set this to the path to the stats binary
*/

#define SPATH "/home/user/Stats/stats"

/* I hate having to do this... now the IRCD_TYPE is set at compile
** time.  This means to change the IRCD_TYPE, you must recompile the 
** service
**
** Only enable ONE - There is no checking or sanity checking on this 
** option yet...
**
** Supported types...
** IRCD_HYBRID
** IRCD_HYB6
** IRCD_DAL
** IRCD_DALNQ
** IRCD_MLN
** IRCD_2_10
**
** Look at the README file for more detailed descriptions of these IRCD
** types.
*/
#define IRCD_HYBRID
/* #define IRCD_HYB6 */
/* #define IRCD_DAL */
/* #define IRCD_MLN */
/* #define IRCD_2_10 */
/* #define IRCD_DALNQ */

/* Set the service into debug mode...
** NOTE:  This is a privacy risk and should NOT be done on any real IRC
** network, only on a test net.
*/

#undef DEBUG

#endif /* CONFIG_H */
