/* Stats - proto.h - Function prototypes
**
** CVS $Id: proto.h,v 1.4 2000/11/30 05:08:29 wcampbel Exp $
**
*/

#ifndef PROTO_H
#define PROTO_H

#include "stats.h"

#ifdef SOLARIS
#define bzero(x, y)       memset(x, '\0', y);
#define bcopy(x,y,z)      memcpy(y,x,z)
#endif /* SOLARIS */

/* Macros that were in m_stats.h */
#define DecreaseOpers(x)        x->opers--; me.opers--;
#define DecreaseUsers(x)        x->users--; me.users--;
#define DecreaseServers()       me.servers--;

/* External variables... */
extern int servsock;
extern char s_StatServ[MAXNICK], s_Spam[8];
extern const char version[];

#ifdef SUPPORT_MSG_UH
extern char s_UH[MAXUSER + MAXHOST + 2];
#endif

#ifdef SUPPORT_MSG_OPERS
extern char s_OPERS[MAXHOST + 7];
#endif

/* sock.c */
extern int ConnectTo(char *, int);
extern void read_loop();
extern void sts(char *, ...);
extern void log(char *, ...);
extern void ResetLogs();
extern char *sctime(time_t);
extern char *sftime(time_t);
#if defined(CRYPT) || defined(MD5)
extern char *make_salt();
#endif /* CRYPT || MD5 */

/* conf.c */
extern void strip(char *);
extern void InitDefaults();
extern void ConfLoad();
extern int GetChanList();
extern void rehash();

/* main.c */
extern void login();
extern void init_statserv();
extern void init_spam();
extern void init_join();
extern void *smalloc(long);
extern char *sstrdup(const char *);
extern unsigned long HASH(const unsigned char *, int);
extern char *strlower(char *);

/* ircd.c */
extern void parse();
extern void privmsg(char *, const char *, char *, ...);
extern void privmsg_list(char *, char *, const char **);
extern void globops(char *, char *, ...);
extern int flood(User *);
extern void SendQuit(User *, int, char *);
extern void Trace(User *);
extern void ParseStats(User *, char);

/* timer.c */
extern void chk();
extern void TimerReset();
extern void TimerSpam();
extern void TimerPings();
extern void TimerMidnight();
extern int is_midnight();

/* statserv.c */
extern void statserv(char *);
extern void spam(char *);

/* users.c */
extern Server *serverlist[S_TABLE_SIZE];
extern User *userlist[U_TABLE_SIZE];
extern MyUser *myuhead;
#ifdef IRCD_2_10
extern void AddUser(char *, char *, char *, Server *);
#else
extern void AddUser(char *, char *, char *, char *);
#endif
extern void DelUser(char *);
extern void Change_User(User *, char *);
extern User *finduser(char *);
extern void UserMode(char *, char *);
extern void init_user_hash();
#ifdef IRCD_2_10
extern void AddServer(char *, int, int, char *, char *);
extern Server *findservtoken(int);
#else
extern void AddServer(char *, int, char *, char *);
#endif
extern void DelServer(char *);
extern Server *findserver(char *);
extern void init_server_hash();
extern void LoadMyUsers();
extern void SaveMyUsers();
extern void DeleteMyUser(char *);
extern MyUser *findmyuser(char *);

/* stats.c */
extern Stats *shead;
extern TLD *tldhead;
extern char *uptime(time_t);
extern TLD *findtld(char *);
extern TLD *AddTLD(User *);
extern void LoadTLD();
extern void init_tld();
extern void IncreaseOpers(Server *);
extern void IncreaseUsers(Server *);
extern void IncreaseServers();
extern void AddStats(Server *);
extern Stats *findstats(char *);
extern void SaveStats();
extern void LoadStats();

/* html.c */
extern void DumpHTML();

#ifdef ENABLE_SET
/* set.c */
extern void DoSet(User *, char *, char *);
#endif

#endif
