/**************************************************************
** set.c - Runtime settings module
**
** $Id: set.c,v 1.13 2000/11/26 23:18:19 wcampbel Exp $
**************************************************************/

/* Only stats.h (for config.h) needs to be loaded
** before the ifdef
*/
/* sigh...the other two must be up here for make depend to work 
** properly...
*/
#include "stats.h"
#include "struct.h"
#include "proto.h"

#ifdef ENABLE_SET

/* This modules will be a little complicated.  There will need to 
** be a function called from the statserv parsing function in order
** to parse the 'set' command's arguments.  We will also need to have
** the dynsave and dynload in here, and all the actions for when you 
** change change certain settings that don't need a restart but aren't
** simply a variable
*/

/* Note that this function will NOT be grafted into the main part of Stats
** until it is complete.  It will also NOT be added to the Makefile and 
** waste space in the binary until it is used.
*/

/* Our actions don't need to have their prototypes in stats.h, just in here */
void SetShowList(User *);

/* This is a complicated function...without parameters, or with the parameter
** "LIST", it will send a list of all settings, with a single argument that's
** NOT "LIST", then show the value of that one setting.  finally, with two
** parameters, set the variable with the value you sent in.  Be careful of
** ones that need numbers....
*/

/* I will have to check ALL strings for lengths.... this is going to be a 
** LOT of work, maybe too much :(
*/

void DoSet(User *u, char *var, char *val)
{
	int gotvar = 0;
	int gotval = 0;

        if (!u->myuser) {
                log("Access Denied (SET) to %s", u->nick);
                privmsg(u->nick, s_StatServ, "Access Denied.");
                return;
        }

	if (var)
		gotvar = 1;

	if (val)
		gotval = 1;

	if (gotvar) {
		if (!strcasecmp(var, "r_time")) {
			if (gotval)
				me.r_time = atoi(val);
			else
				privmsg(u->nick, s_StatServ, "Value of r_time (Reconnection time): %d", me.r_time);
		} else if (!strcasecmp(var, "want_privmsg")) {
			if (gotval) {
				int t = atoi(val);
				if ((t != 1) && (t != 0))
					privmsg(u->nick, s_StatServ, "want_privmsg may only be set to 1 or 0");
				else
					me.want_privmsg = t;
			} else
				privmsg(u->nick, s_StatServ, "Value of want_privmsg (Use PRIVMSG instead of NOTICE): %d", me.want_privmsg);
		} else if (!strcasecmp(var, "onlyopers")) {
			if (gotval) {
				int t = atoi(val);
				if ((t != 1) && (t != 0))
					privmsg(u->nick, s_StatServ, "opersonly may only be set to 1 or 0");
				else
					me.onlyopers = t;
			} else
				privmsg(u->nick, s_StatServ, "Value of onlyopers (Only Opers may access the service): %d", me.onlyopers);
		} else if (!strcasecmp(var, "hide_services")) {
			if (gotval) {
				int t = atoi(val);
				if ((t != 1) && (t != 0))
					privmsg(u->nick, s_StatServ, "hide_services may only be set to 1 or 0");
				else
					me.hide_services = t;
			} else
				privmsg(u->nick, s_StatServ, "Value of hide_services (Hide the network's services server): %d", me.hide_services);
		} else if (!strcasecmp(var, "services_name")) {
			if (gotval)
				strcpy(me.services_name, val);
			else
				privmsg(u->nick, s_StatServ, "Value of services_name (The name of the network's services server): %s", me.services_name);
		} else if (!strcasecmp(var, "lag_time")) {
			if (gotval)
				me.lag_time = atoi(val);
			else
				privmsg(u->nick, s_StatServ, "Value of lag_time (The length of time a server can lag before reporting it): %d", me.lag_time);
		} else if (!strcasecmp(var, "flood")) {
			if (gotval) {
				int t = atoi(val);
				if (t == 1) {
					privmsg(u->nick, s_StatServ, "flood cannot be set to 1, defaulting to 2");
					t = 2;
				}
				else
					me.flood = t;
			} else
				privmsg(u->nick, s_StatServ, "Value of flood (The number of PRIVMSG messages before considering the user flooding, 0 = disabled, 1 is not allowed): %d", me.flood);
		} else if (!strcasecmp(var, "lag_notices")) {
			if (gotval) {
				int t = atoi(val);
				if ((t != 1) && (t != 0))
					privmsg(u->nick, s_StatServ, "lag_notices may only be set to 1 or 0");
				else
					me.lag_notices = t;
			} else 
				privmsg(u->nick, s_StatServ, "Value of lag_notices (Send lag notices via WALLOPS/GLOBOPS): %d", me.lag_notices);
		} else if (!strcasecmp(var, "flood_time")) {
			if (gotval)
				me.flood_time = atoi(val);
			else
				privmsg(u->nick, s_StatServ, "Value of flood_time (The time that messages are increase the flood count): %d", me.flood_time);
		} else if (!strcasecmp(var, "flood_action")) {
			if (gotval) {
				int t = atoi(val);
				if ((t != 1) && (t != 0))
					privmsg(u->nick, s_StatServ, "flood_action may only be set to 1 or 0");
				else
					me.flood_action = t;
			} else
				privmsg(u->nick, s_StatServ, "Value of flood_action (Ignore a flooder instead of KILL the flooder): %d", me.flood_action);
		} else if (!strcasecmp(var, "url")) {
			if (gotval)
				strcpy(me.url, val);
			else
				privmsg(u->nick, s_StatServ, "Value of url (The URL where the HTML dump is accessible): %s", me.url);
		} else if (!strcasecmp(var, "enable_html")) {
			if (gotval) {
                                int t = atoi(val);
                                if ((t != 1) && (t != 0))
                                        privmsg(u->nick, s_StatServ, "enable_html may only be set to 1 or 0");
                                else
                                        me.enable_html = t;
                        } else
                                privmsg(u->nick, s_StatServ, "Value of enable_html (Create an HTML Output dump): %d", me.enable_html);
		} else if (!strcasecmp(var, "list")) {
			SetShowList(u);
		} else {
			privmsg(u->nick, s_StatServ, "Invalid setting");
		}
/* NOTE:  Put the default error message when giving an invalid setting here */
	} else {
		/* Here is where we process requests LIST requests (or ones 
		** without a parameter
		*/
		SetShowList(u);
	}
}

void SetShowList(User *u)
{
	/* rien */
}

#endif
